==> tl-0.4.tar.gz: tl-0.4/tl/plugs/core/plug.py <==
# tl/plugs/core/plug.py
#
#

""" plugin management. """

## tl imports

from tl.lib.commands import cmnds
from tl.lib.examples import examples
from tl.lib.boot import default_plugins, plugin_packages, remove_plugin, update_mod
from tl.utils.exception import handle_exception, exceptionmsg
from tl.lib.boot import savecmndtable, savepluginlist, update_mod
from tl.lib.errors import NoSuchPlugin, RequireError
from tl.lib.boot import plugenable, plugdisable

## basic imports

import os
import logging

## plug-enable command

def handle_plugenable(bot, event):
    """ arguments" <plugname> - enable a plugin. """
    if not event.rest: event.missing("<plugname>") ; return
    if "." in event.rest: mod = event.rest
    else: mod = bot.plugs.getmodule(event.rest)
    if not mod: event.reply("can't find module for %s" % event.rest) ; return
    event.reply("reloading and enabling %s" % mod)
    plugenable(mod)
    bot.enable(mod)
    bot.plugs.reload(mod, force=True)
    update_mod(mod)
    event.done()

cmnds.add("plug-enable", handle_plugenable, ["OPER", ])
examples.add("plug-enable", "enable a plugin", "plug-enable rss")

## plug-disable command

def handle_plugdisable(bot, event):
    """ arguments: <plugname> - disable a plugin. """
    if not event.rest: event.missing("<plugin>") ; return
    mod = bot.plugs.getmodule(event.rest)
    if mod in default_plugins: event.reply("can't remove a default plugin") ; return
    if not mod: event.reply("can't find module for %s" % event.rest) ; return
    event.reply("unloading and disabling %s" % mod)
    bot.plugs.unload(mod)
    plugdisable(mod)
    bot.disable(mod)
    event.done()

cmnds.add("plug-disable", handle_plugdisable, ["OPER", ])
examples.add("plug-disable", "disable a plugin", "plug-disable rss")

## plug-reload command

def handle_plugreload(bot, ievent):
    """ arguments: <list of plugnames> - reload list of plugins. """
    try: pluglist = ievent.args
    except (TypeError, IndexError): ievent.missing('<list of plugnames>') ; return
    ievent.untildone = True
    reloaded = []
    errors = []
    for plug in pluglist:
        if not plug: logging.error("empty plug name in %s" % str(pluglist)) ; continue
        modname = bot.plugs.getmodule(plug)
        if not modname: errors.append("can't find %s plugin" % plug) ; continue
        try:
            loaded = bot.plugs.reload(modname, force=True, showerror=True)
            for plug in loaded:
                if plug:
                    reloaded.append(plug)
                    logging.warn("%s reloaded" % plug) 
                else: logging.error("got no result for %s reload" % modname)
        except RequireError as ex: errors.append(str(ex)) ; continue
        except NoSuchPlugin: errors.append("can't find %s plugin" % plug) ; continue
        except ImportError as ex:
            if plug in str(ex):
                logging.warn('%s - %s' % (modname, str(ex)))
                continue
            errors.append(exceptionmsg())
    if False and opts.dosave:
        for modname in reloaded:
           if modname: update_mod(modname)
    if errors:
         logging.error("there were errors: %s" %  str(errors))
         ievent.reply('errors: ', errors)
    if reloaded: ievent.reply('reloaded: ', reloaded)
    ievent.done()

cmnds.add('plug-reload', handle_plugreload, 'OPER')
examples.add('plug-reload', 'plug-reload <plugin>', 'plug-reload core')

==> tl-0.5.tar.gz: tl-0.5/tl/plugs/core/plug.py <==
# tl/plugs/core/plug.py
#
#

""" plugin management. """

## tl imports

from tl.commands import cmnds
from tl.examples import examples
from tl.boot import default_plugins, plugin_packages, remove_plugin, update_mod
from tl.utils.exception import handle_exception, exceptionmsg
from tl.boot import savecmndtable, saveplugins, update_mod
from tl.errors import NoSuchPlugin, RequireError
from tl.boot import plugenable, plugdisable

## basic imports

import os
import logging

## plug-enable command

def handle_plugenable(bot, event):
    """ arguments" <plugname> - enable a plugin. """
    if not event.rest: event.missing("<plugname>") ; return
    if "." in event.rest: mod = event.rest
    else: mod = bot.plugs.getmodule(event.rest)
    if not mod: event.reply("can't find module for %s" % event.rest) ; return
    event.reply("reloading and enabling %s" % mod)
    plugenable(mod)
    bot.enable(mod)
    bot.plugs.reload(mod, force=True)
    update_mod(mod)
    event.done()

cmnds.add("plug-enable", handle_plugenable, ["OPER", ])
examples.add("plug-enable", "enable a plugin", "plug-enable rss")

## plug-disable command

def handle_plugdisable(bot, event):
    """ arguments: <plugname> - disable a plugin. """
    if not event.rest: event.missing("<plugin>") ; return
    mod = bot.plugs.getmodule(event.rest)
    if mod in default_plugins: event.reply("can't remove a default plugin") ; return
    if not mod: event.reply("can't find module for %s" % event.rest) ; return
    event.reply("unloading and disabling %s" % mod)
    bot.plugs.unload(mod)
    plugdisable(mod)
    bot.disable(mod)
    event.done()

cmnds.add("plug-disable", handle_plugdisable, ["OPER", ])
examples.add("plug-disable", "disable a plugin", "plug-disable rss")

## plug-reload command

def handle_plugreload(bot, ievent):
    """ arguments: <list of plugnames> - reload list of plugins. """
    try: pluglist = ievent.args
    except (TypeError, IndexError): ievent.missing('<list of plugnames>') ; return
    ievent.untildone = True
    reloaded = []
    errors = []
    for plug in pluglist:
        if not plug: logging.error("empty plug name in %s" % str(pluglist)) ; continue
        modname = bot.plugs.getmodule(plug)
        if not modname: errors.append("can't find %s plugin" % plug) ; continue
        try:
            loaded = bot.plugs.reload(modname, force=True, showerror=True)
            for plug in loaded:
                if plug:
                    reloaded.append(plug)
                    logging.warn("%s reloaded" % plug) 
                else: logging.error("got no result for %s reload" % modname)
        except RequireError as ex: errors.append(str(ex)) ; continue
        except NoSuchPlugin: errors.append("can't find %s plugin" % plug) ; continue
        except ImportError as ex:
            if plug in str(ex):
                logging.warn('%s - %s' % (modname, str(ex)))
                continue
            errors.append(exceptionmsg())
    if False and opts.dosave:
        for modname in reloaded:
           if modname: update_mod(modname)
    if errors:
         logging.error("there were errors: %s" %  str(errors))
         ievent.reply('errors: ', errors)
    if reloaded: ievent.reply('reloaded: ', reloaded)
    ievent.done()

cmnds.add('plug-reload', handle_plugreload, 'OPER')
examples.add('plug-reload', 'plug-reload <plugin>', 'plug-reload core')
